@@ -35,7 +35,6 @@ describe 'tripleo::profile::base::cinder::api' do
         is_expected.to contain_class('tripleo::profile::base::cinder::authtoken')
         is_expected.to_not contain_class('cinder::api')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
-        is_expected.to_not contain_class('cinder::ceilometer')
       end
     end
 
@@ -55,7 +54,6 @@ describe 'tripleo::profile::base::cinder::api' do
           :keymgr_backend => 'cinder.keymgr.conf_key_mgr.ConfKeyManager',
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to contain_class('cinder::ceilometer')
       end
     end
 
@@ -71,7 +69,6 @@ describe 'tripleo::profile::base::cinder::api' do
         is_expected.to contain_class('tripleo::profile::base::cinder::authtoken')
         is_expected.to_not contain_class('cinder::api')
         is_expected.to_not contain_class('tripleo::profile::base::apache')
-        is_expected.to_not contain_class('cinder::ceilometer')
       end
     end
 
@@ -90,7 +87,6 @@ describe 'tripleo::profile::base::cinder::api' do
           :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to contain_class('cinder::ceilometer')
         is_expected.to contain_cinder__type('tripleo')
       end
     end
@@ -110,7 +106,6 @@ describe 'tripleo::profile::base::cinder::api' do
           :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
         )
         is_expected.to contain_class('tripleo::profile::base::apache')
-        is_expected.to contain_class('cinder::ceilometer')
         is_expected.to_not contain_cinder__type('tripleo')
       end
     end
